@@ -62,26 +62,56 @@ def calc_phase(frequencies, init_phases, length = None, fs=None):
     
     return 2*_np.pi*_np.cumsum(frequencies)*dt+init_phases
 
-#-------------------------------------
-def _check_size(array, size=None):
+
+#---------------------------------------
+def to_beatsignal(sig_ref, sig_delayed,
+                  reduced_ratio=None, hilbert = False):
+    '''
+    Mixing reference and delayed (received)
+        signals to create the beat one.
     
-    array = _np.asarray(array, dtype = float)
+    Parameters
+    -------------
+    sig_ref: 1d ndarray,
+        reference signal
+    sig_delayed: 1d ndarray,
+        dealyed signal
+    reduced_ratio: float,
+        pooling (or downsampling) ratio as fs_old/fs_new,
+        where fs is the sampling frequency,
+    hilbert: bool,
+        If ture, hilbert transform will be carried out additionally.
     
-    if size is None:
-        return array
-    
-    size = int(size)
-    
-    if array.size==1:
-        return _np.ones(size, dtype=float)*array 
-    else:
-        if array.size>=size:
-            return array[:size]
+    Returns
+    -------------
+    sig_beat: 1d ndarray,
+        beat signal.
+    '''
+    sig_beat = sig_ref*_np.conj(sig_delayed);
+    if reduced_ratio is not None:
         
+        len_reduce = int(len(sig_ref)/reduced_ratio)
+        
+        sp = _np.fft.fft(sig_beat)
+        
+        if hilbert is False:
+            sp = _np.concatenate((sp[:len_reduce//2],
+                                 [sp[len(sp)//2]],
+                                 sp[len(sp) - len_reduce//2 +1:]))
         else:
-            last  = _np.ones(size-array.size, 
-                            dtype=float)*array[-1]
-            return _np.concatenate((array,last))
+            sp = _np.concatenate((sp[:len_reduce//2],
+                                 [sp[len(sp)//2]],
+                                 _np.zeros(len_reduce//2 +1,
+                                          dtype=complex)))
+            
+        sig_beat = _np.fft.ifft(sp)
+    else:
+        if hilbert:
+            sp = _np.fft.fft(sig_beat)
+            sp[len(sp)//2:] = 0
+            sig_beat = _np.fft.ifft(sp)
+ 
+    return sig_beat
 
 #-------------------------------
 def linear_frequency(f0, delta_f, length, fs):
@@ -109,6 +139,7 @@ def linear_frequency(f0, delta_f, length, fs):
     length = int(length)
     t = _np.arange(length)/fs
     return f0+delta_f*t/((length/fs))
+
 #-------------------------------
 def symetric_linear_frequency(f0, delta_f, length, fs):
     '''
@@ -276,53 +307,52 @@ def sin_phase_frequency(f0, delta_f, length, fs, phi0=0, phiN=_np.pi/4):
     freqm = _np.sin(2*_np.pi*t/(tm*divider)+phi0)
     return (f0)+delta_f*(freqm-min(freqm))/(max(freqm)-min(freqm))
 
-#---------------------------------------
-def to_beatsignal(sig_ref, sig_delayed,
-                  reduced_ratio=None, hilbert = False):
+#-------------------------------------
+def exp_decay_frequency(f0, delta_f, decay, length, fs): 
     '''
-    Mixing reference and delayed (received)
-        signals to create the beat one.
+    Exponential Decay frequency to time relation.
+      ..math::
+      f(n) = f0 + delta_f*exp(-2*pi*alpha*n/N),
+      n=0,...,N-1
+
+    Paramteres
+    ------------
+    f0: float,
+      carried frequency.
+    delta_f: float,
+      frequency bandwidth.
+    decay: float,
+      coefficient on exp decay.  
+    length: int,
+      length of relation.
+    fs: float,
+      sampling frequency.
     
-    Parameters
-    -------------
-    sig_ref: 1d ndarray,
-        reference signal
-    sig_delayed: 1d ndarray,
-        dealyed signal
-    reduced_ratio: float,
-        pooling (or downsampling) ratio as fs_old/fs_new,
-        where fs is the sampling frequency,
-    hilbert: bool,
-        If ture, hilbert transform will be carried out additionally.
-    
-    Returns
-    -------------
-    sig_beat: 1d ndarray,
-        beat signal.
+    Return
+    ----------
+    freq: 1d ndarray.
     '''
-    sig_beat = sig_ref*_np.conj(sig_delayed);
-    if reduced_ratio is not None:
-        
-        len_reduce = int(len(sig_ref)/reduced_ratio)
-        
-        sp = _np.fft.fft(sig_beat)
-        
-        if hilbert is False:
-            sp = _np.concatenate((sp[:len_reduce//2],
-                                 [sp[len(sp)//2]],
-                                 sp[len(sp) - len_reduce//2 +1:]))
-        else:
-            sp = _np.concatenate((sp[:len_reduce//2],
-                                 [sp[len(sp)//2]],
-                                 _np.zeros(len_reduce//2 +1,
-                                          dtype=complex)))
-            
-        sig_beat = _np.fft.ifft(sp)
+    t = np.arange(length)/fs
+    tm = length/fs
+    return (f0)+delta_f*np.exp(-2*decay*np.pi*t/tm)
+
+#-------------------------------------
+def _check_size(array, size=None):
+    
+    array = _np.asarray(array, dtype = float)
+    
+    if size is None:
+        return array
+    
+    size = int(size)
+    
+    if array.size==1:
+        return _np.ones(size, dtype=float)*array 
     else:
-        if hilbert:
-            sp = _np.fft.fft(sig_beat)
-            sp[len(sp)//2:] = 0
-            sig_beat = _np.fft.ifft(sp)
+        if array.size>=size:
+            return array[:size]
         
-    #TODO: add pooling
-    return sig_beat
+        else:
+            last  = _np.ones(size-array.size, 
+                            dtype=float)*array[-1]
+            return _np.concatenate((array,last))
